@@ -9,6 +9,7 @@ Main file containing the mito widget.
 """
 import json
 import os
+from sysconfig import get_python_version
 import time
 from typing import Any, Dict, List, Optional, Union
 
@@ -21,7 +22,7 @@ from mitosheet.api import API
 from mitosheet.data_in_mito import DataTypeInMito
 from mitosheet.errors import (MitoError, get_recent_traceback,
                               make_execution_error)
-from mitosheet.mito_config import MitoConfig
+from mitosheet.enterprise.mito_config import MitoConfig
 from mitosheet.saved_analyses import write_analysis
 from mitosheet.steps_manager import StepsManager
 from mitosheet.telemetry.telemetry_utils import (MITOSHEET_HELPER_PRIVATE, log, log_event_processed,
@@ -33,12 +34,7 @@ from mitosheet.user.db import USER_JSON_PATH, get_user_field
 from mitosheet.user.location import is_in_google_colab, is_in_vs_code
 from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_CHECKLISTS,
                                     UJ_RECEIVED_TOURS, UJ_USER_EMAIL)
-from mitosheet.user.utils import is_excel_import_enabled, is_pro, is_running_test
-
-try:
-    from mitosheet_helper_config import MITO_ENTERPRISE_CONFIGURATION 
-except ImportError:
-    MITO_ENTERPRISE_CONFIGURATION = None
+from mitosheet.user.utils import get_pandas_version, is_pro, is_running_test
 
 
 class MitoWidget(DOMWidget):
@@ -57,7 +53,7 @@ class MitoWidget(DOMWidget):
     analysis_data_json = t.Unicode('').tag(sync=True) # type: ignore
     user_profile_json = t.Unicode('').tag(sync=True) # type: ignore
     
-    def __init__(self, *args: List[Union[pd.DataFrame, str]], analysis_to_replay: str=None):
+    def __init__(self, *args: List[Union[pd.DataFrame, str]], analysis_to_replay: Optional[str]=None):
         """
         Takes a list of dataframes and strings that are paths to CSV files
         passed through *args.
@@ -68,7 +64,7 @@ class MitoWidget(DOMWidget):
         # Set up the state container to hold private widget state
         self.steps_manager = StepsManager(args, analysis_to_replay=analysis_to_replay)
 
-        self.mito_config = MitoConfig(MITO_ENTERPRISE_CONFIGURATION)
+        self.mito_config = MitoConfig() # type: ignore
 
         # Set up message handler
         self.on_msg(self.receive_message)
@@ -108,7 +104,8 @@ class MitoWidget(DOMWidget):
             'isPro': is_pro(),
             'telemetryEnabled': telemetry_turned_on(),
             # Static over a single analysis
-            'excelImportEnabled': is_excel_import_enabled(),
+            'pythonVersion': get_python_version(),
+            'pandasVersion': get_pandas_version(),
             'isLocalDeployment': self.is_local_deployment,
             'shouldUpgradeMitosheet': self.should_upgrade_mitosheet,
             'numUsages': self.num_usages,
@@ -274,7 +271,7 @@ class MitoWidget(DOMWidget):
 
 def sheet(
         *args: Any,
-        analysis_to_replay: str=None, # This is the parameter that tracks the analysis that you want to replay (NOTE: requires a frontend to be replayed!)
+        analysis_to_replay: Optional[str]=None, # This is the parameter that tracks the analysis that you want to replay (NOTE: requires a frontend to be replayed!)
         view_df: bool=False, # We use this param to log if the mitosheet.sheet call is created from the df output button,
         # NOTE: if you add named variables to this function, make sure argument parsing on the front-end still
         # works by updating the getArgsFromCellContent function.
