@@ -5,9 +5,11 @@
 # Distributed under the terms of the GPL License.
 from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
-from mitosheet.code_chunks.code_chunk import CodeChunk
-from mitosheet.code_chunks.step_performers.column_steps.delete_column_code_chunk import DeleteColumnsCodeChunk
 
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.step_performers.column_steps.delete_column_code_chunk import \
+    DeleteColumnsCodeChunk
+from mitosheet.errors import raise_error_if_column_ids_do_not_exist
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.utils import get_param
@@ -32,6 +34,13 @@ class DeleteColumnStepPerformer(StepPerformer):
         sheet_index: int = get_param(params, 'sheet_index')
         column_ids: List[ColumnID] = get_param(params, 'column_ids')
 
+        raise_error_if_column_ids_do_not_exist(
+            'delete column',
+            prev_state,
+            sheet_index,
+            column_ids
+        )
+
         # Make a post state, that is a deep copy
         post_state = prev_state.copy(deep_sheet_indexes=[sheet_index])
 
@@ -91,7 +100,8 @@ def _delete_column_id(
 
     # And then update all the state variables removing this column from the state
     del state.column_spreadsheet_code[sheet_index][column_id]
-    del state.column_format_types[sheet_index][column_id]
+    if column_id in state.df_formats[sheet_index]['columns']:
+        del state.df_formats[sheet_index]['columns'][column_id]
 
     # Clean up the IDs
     state.column_ids.delete_column_id(sheet_index, column_id)
