@@ -20,6 +20,11 @@ pandas_pre_1_only = pytest.mark.skipif(
     reason='This test only runs on earlier versions of Pandas. API inconsistencies make it fail on earlier versions'
 )
 
+pandas_post_0_24_0_only = pytest.mark.skipif(
+    is_prev_version(pd.__version__, '0.24.0'), 
+    reason='This test only runs on later versions of Pandas. API inconsistencies make it fail on earlier versions'
+)
+
 pandas_post_1_only = pytest.mark.skipif(
     pd.__version__.startswith('0.'), 
     reason='This test only runs on later versions of Pandas. API inconsistencies make it fail on earlier versions'
@@ -35,6 +40,11 @@ pandas_post_1_4_only = pytest.mark.skipif(
     reason='This test only runs on later versions of Pandas. API inconsistencies make it fail on earlier versions'
 )
 
+pandas_post_1_5_only = pytest.mark.skipif(
+    is_prev_version(pd.__version__, '1.5.0'), 
+    reason='This test only runs on later versions of Pandas. API inconsistencies make it fail on earlier versions'
+)
+
 pandas_pre_1_2_only = pytest.mark.skipif(
     not is_prev_version(pd.__version__, '1.2.0'), 
     reason='This test only runs on later versions of Pandas. API inconsistencies make it fail on earlier versions'
