@@ -3,8 +3,9 @@
 
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
+from mitosheet.code_chunks.step_performers.import_steps.simple_import_code_chunk import DEFAULT_DECIMAL, DEFAULT_DELIMETER, DEFAULT_ENCODING, DEFAULT_ERROR_BAD_LINES, DEFAULT_SKIPROWS
 from mitosheet.data_in_mito import DataTypeInMito
-from mitosheet.mito_config import DEFAULT_SUPPORT_EMAIL, MEC_CONFIG_KEY_SUPPORT_EMAIL, MEC_CONFIG_KEY_VERSION, MitoConfig
+from mitosheet.enterprise.mito_config import DEFAULT_MITO_CONFIG_SUPPORT_EMAIL, MitoConfig
 from mitosheet.state import (
     DATAFRAME_SOURCE_DUPLICATED,
     DATAFRAME_SOURCE_IMPORTED,
@@ -197,7 +198,7 @@ def test_graph_safety_filter_cutoff_matches():
 
 def test_mito_enterprise_keys_match():
     mito_enterprise_config_keys = get_enum_from_ts_file("./src/types.tsx", "MitoEnterpriseConfigKey")
-    assert set(mito_enterprise_config_keys.values()) == set(MitoConfig(None).get_mito_config().keys())
+    assert set(mito_enterprise_config_keys.values()) == set(MitoConfig().get_mito_config().keys())
 
 def test_user_profile_defaults_matches():
     user_profile_support_email = get_constant_from_ts_file(
@@ -205,7 +206,7 @@ def test_user_profile_defaults_matches():
         'DEFAULT_SUPPORT_EMAIL'
     )
 
-    assert user_profile_support_email == f"\'{DEFAULT_SUPPORT_EMAIL}\'"
+    assert user_profile_support_email == f"\'{DEFAULT_MITO_CONFIG_SUPPORT_EMAIL}\'"
 
 def test_update_events_enum_defined():
     update_types = get_enum_from_ts_file("./src/types.tsx", "UpdateType")
@@ -214,3 +215,21 @@ def test_update_events_enum_defined():
     for UPDATE in UPDATES:
         assert UPDATE['event_type'] in update_types.values()
 
+
+def test_update_events_default_import_decimal():
+    default_delimiter = get_constant_from_ts_file("./src/components/import/CSVImportConfigScreen.tsx", "DEFAULT_DELIMETER")
+    default_encoding = get_constant_from_ts_file("./src/components/import/CSVImportConfigScreen.tsx", "DEFAULT_ENCODING")
+    _default_decimal = get_constant_from_ts_file("./src/components/import/CSVImportConfigScreen.tsx", "DEFAULT_DECIMAL")
+    default_skiprows = get_constant_from_ts_file("./src/components/import/CSVImportConfigScreen.tsx", "DEFAULT_SKIPROWS")
+    default_error_bad_lines = get_constant_from_ts_file("./src/components/import/CSVImportConfigScreen.tsx", "DEFAULT_ERROR_BAD_LINES")
+
+    # We must make sure the DEFAULT_DECIMAL reference to the Decimal enum is correct.
+    decimalEnum = get_enum_from_ts_file("./src/components/import/CSVImportConfigScreen.tsx", "Decimal")
+    default_decimal = decimalEnum[_default_decimal.split('.')[1]]
+    
+    assert default_delimiter == f'"{DEFAULT_DELIMETER}"'
+    assert default_encoding == f'"{DEFAULT_ENCODING}"'
+    assert default_decimal == f'{DEFAULT_DECIMAL}'
+    assert int(default_skiprows) == DEFAULT_SKIPROWS
+    assert bool(default_error_bad_lines) == DEFAULT_ERROR_BAD_LINES
+
