@@ -19,7 +19,7 @@ import pandas as pd
 from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.parser import parse_formula
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.types import ColumnHeader, ColumnID, DataframeFormat, GraphID, MultiLevelColumnHeader
+from mitosheet.types import ColumnHeader, ColumnID, DataframeFormat, GraphID, MultiLevelColumnHeader, FilterOnColumnID, FilterOnColumnHeader
 from mitosheet.utils import NpEncoder, dfs_to_array_for_json, get_new_id
 
 
@@ -542,24 +542,32 @@ class MitoWidgetTestWrapper:
             pivot_rows: List[ColumnHeader],
             pivot_columns: List[ColumnHeader],
             values: Dict[ColumnHeader, List[str]],
+            pivot_filters: Optional[List[FilterOnColumnHeader]]=None,
             flatten_column_headers: bool=True,
-            destination_sheet_index: int=None,
-            step_id: str=None
+            destination_sheet_index: Optional[int]=None,
+            step_id: Optional[str]=None
         ) -> bool:
 
+        get_column_id_by_header = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header
+
         rows_ids = [
-            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            get_column_id_by_header(sheet_index, column_header)
             for column_header in pivot_rows
         ]
         columns_ids = [
-            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            get_column_id_by_header(sheet_index, column_header)
             for column_header in pivot_columns
         ]
         values_column_ids_map = {
-            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header): value
+            get_column_id_by_header(sheet_index, column_header): value
             for column_header, value in values.items()
         }
 
+        pivot_filters_ids: List[FilterOnColumnID] = [
+            {'column_id': get_column_id_by_header(sheet_index, pf['column_header']), 'filter': pf['filter']} 
+            for pf in pivot_filters
+        ] if pivot_filters is not None else []
+
         return self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -573,6 +581,7 @@ class MitoWidgetTestWrapper:
                     'pivot_columns_column_ids': columns_ids,
                     'values_column_ids_map': values_column_ids_map,
                     'destination_sheet_index': destination_sheet_index,
+                    'pivot_filters': pivot_filters_ids,
                     'flatten_column_headers': flatten_column_headers
                 }
             }
@@ -649,7 +658,7 @@ class MitoWidgetTestWrapper:
             sheet_index: int, 
             column_header: ColumnHeader,
             sort_direction: str,
-            step_id: str=None
+            step_id: Optional[str]=None
         ) -> bool:
 
         column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
@@ -701,7 +710,7 @@ class MitoWidgetTestWrapper:
         )
 
     @check_transpiled_code_after_call
-    def rename_column(self, sheet_index: int, old_column_header: ColumnHeader, new_column_header: ColumnHeader, level: int=None) -> bool:
+    def rename_column(self, sheet_index: int, old_column_header: ColumnHeader, new_column_header: ColumnHeader, level: Optional[int]=None) -> bool:
 
         column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
             sheet_index,
@@ -769,7 +778,15 @@ class MitoWidgetTestWrapper:
         )
 
     @check_transpiled_code_after_call
-    def simple_import(self, file_names: List[str], delimeters: Optional[List[str]]=None, encodings: Optional[List[str]]=None, error_bad_lines: Optional[List[bool]]=None) -> bool:
+    def simple_import(
+        self, 
+        file_names: List[str], 
+        delimeters: Optional[List[str]]=None, 
+        encodings: Optional[List[str]]=None, 
+        decimals: Optional[List[str]]=None, 
+        skiprows: Optional[List[int]]=None,
+        error_bad_lines: Optional[List[bool]]=None
+    ) -> bool:
         return self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -781,13 +798,15 @@ class MitoWidgetTestWrapper:
                     'file_names': file_names,
                     'delimeters': delimeters,
                     'encodings': encodings,
+                    'decimals': decimals,
+                    'skiprows': skiprows,
                     'error_bad_lines': error_bad_lines,
                 }
             }
         )
 
     @check_transpiled_code_after_call
-    def excel_import(self, file_name: str, sheet_names: List[str], has_headers: bool, skiprows: int) -> bool:
+    def excel_import(self, file_name: str, sheet_names: List[str], has_headers: bool, skiprows: int, decimal: Optional[str]=None) -> bool:
         return self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -800,6 +819,7 @@ class MitoWidgetTestWrapper:
                     'sheet_names': sheet_names,
                     'has_headers': has_headers,
                     'skiprows': skiprows,
+                    'decimal': decimal
                 }   
             }
         )
@@ -940,7 +960,7 @@ class MitoWidgetTestWrapper:
         )
 
     @check_transpiled_code_after_call
-    def replay_analysis(self, analysis_name: str, step_import_data_list_to_overwrite: List[Dict[str, Any]]=None) -> bool:
+    def replay_analysis(self, analysis_name: str, step_import_data_list_to_overwrite: Optional[List[Dict[str, Any]]]=None) -> bool:
         return self.mito_widget.receive_message(
             self.mito_widget,
             {
@@ -1022,7 +1042,7 @@ class MitoWidgetTestWrapper:
         legend_orientation: Optional[str]='v',
         legend_x: Optional[number]=None,
         legend_y: Optional[number]=None,
-        step_id: str=None,
+        step_id: Optional[str]=None,
         paper_bgcolor: str=DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT,
         plot_bgcolor: str=DO_NOT_CHANGE_PLOT_BGCOLOR_DEFAULT,
         barmode: Optional[str]=None,
@@ -1358,7 +1378,7 @@ class MitoWidgetTestWrapper:
         return self.mito_widget.steps_manager.curr_step.final_defined_state.df_formats[sheet_index]
         
 
-def create_mito_wrapper(sheet_one_A_data: List[Any], sheet_two_A_data: List[Any]=None) -> MitoWidgetTestWrapper:
+def create_mito_wrapper(sheet_one_A_data: List[Any], sheet_two_A_data: Optional[List[Any]]=None) -> MitoWidgetTestWrapper:
     """
     Returns a MitoWidgetTestWrapper instance wrapped around a MitoWidget
     that contains just a column A, containing sheet_one_A_data.
@@ -1382,7 +1402,7 @@ def create_mito_wrapper_dfs(*args: pd.DataFrame) -> MitoWidgetTestWrapper:
     mito_widget = sheet(*args)
     return MitoWidgetTestWrapper(mito_widget)
 
-def make_multi_index_header_df(data: Dict[Union[str, int], List[Any]], column_headers: List[ColumnHeader], index: List[Any]=None) -> pd.DataFrame:
+def make_multi_index_header_df(data: Dict[Union[str, int], List[Any]], column_headers: List[ColumnHeader], index: Optional[List[Any]]=None) -> pd.DataFrame:
     """
     A helper function that allows you to easily create a multi-index
     header dataframe. 
